==> deepin-image-viewer_5.7.8.orig.tar.xz: deepin-image-viewer-5.7.8/src/translations/deepin-image-viewer_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>Application</name>
    <message>
        <source>Image Viewer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CountingThread</name>
    <message>
        <source>Images</source>
        <translation>Εικόνες</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation type="unfinished">Πληροφοριες εικονας</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageView</name>
    <message>
        <source>This file contains multiple pages, please use Evince to view all pages.</source>
        <translation>Αυτό το αρχείο περιέχει πολλές σελίδες, χρησιμοποιήστε το Evince για να δείτε όλες τις σελίδες.</translation>
    </message>
</context>
<context>
    <name>Importer</name>
    <message>
        <source>Open Directory</source>
        <translation type="vanished">Άνοιγμα τοποθεσίας</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>Δεν έχετε δικαίωμα να δείτε αυτή την εικόνα</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Ακύρωση</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Τύπος</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>Ημερομηνία επεξεργασίας</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>Μέγεθος αρχείου</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>Λειτουργία έκθεσης</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>Πρόγραμμα έκθεσης</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>Χρόνος έκθεσης</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>Φλάς</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>Διάφραγμα</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>Εστίαση</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>Μέγιστο Διάφραγμα</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>Λειτουργία μέτρησης</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>Ισορροπία λευκού</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>Ένταση φλάς</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>Μοντέλο φακού</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>Χρωματικός χώρος</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>Μοντέλο κάμερας</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tag</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PrintOptionsPage</name>
    <message>
        <source>No scaling</source>
        <translation>χωρίς κλίμακα</translation>
    </message>
    <message>
        <source>Fit page to image</source>
        <translation>Προσαρμογή σελίδας σε εικόνα</translation>
    </message>
    <message>
        <source>Fit image to page</source>
        <translation>Προσαρμογή εικόνας σε σελίδα</translation>
    </message>
    <message>
        <source>Scale to:</source>
        <translation>Θέσε κλίμακα σε:</translation>
    </message>
    <message>
        <source>Millimeters</source>
        <translation>Χιλιοστά</translation>
    </message>
    <message>
        <source>Centimeters</source>
        <translation>Εκατοστά</translation>
    </message>
    <message>
        <source>Inches</source>
        <translation>Ίντσες</translation>
    </message>
    <message>
        <source>Image Position</source>
        <translation>Θέση εικόνας</translation>
    </message>
    <message>
        <source>Scaling</source>
        <translation>Κλιμάκωση</translation>
    </message>
    <message>
        <source>Image Settings</source>
        <translation>Ρυθμίσεις εικόνας</translation>
    </message>
</context>
<context>
    <name>PrintPreviewDialog</name>
    <message>
        <source>Image Settings</source>
        <translation type="obsolete">Ρυθμίσεις εικόνας</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Blinds</source>
        <translation type="vanished">Περσίδες</translation>
    </message>
    <message>
        <source>Switcher</source>
        <translation type="vanished">πολυπλέκτης</translation>
    </message>
    <message>
        <source>Sliding</source>
        <translation type="vanished">Κύλιση</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScanPathsDialog</name>
    <message>
        <source>Select Directory</source>
        <translation>Επιλογή φακέλου</translation>
    </message>
    <message>
        <source>This directory is disabled to sync</source>
        <translation>ο συγχρονισμός είναι σωστός για το φάκελο</translation>
    </message>
    <message>
        <source>Add folder</source>
        <translation>Προσθήκη φακέλου</translation>
    </message>
    <message>
        <source>Sync Directory Management</source>
        <translation>Διαχειριστής συγχρονισμού</translation>
    </message>
    <message>
        <source>The directory list is empty</source>
        <translation>Η λίστα των φακέλων είναι άδεια</translation>
    </message>
</context>
<context>
    <name>ScanPathsItem</name>
    <message>
        <source>Cancel sync</source>
        <translation>Ακύρωση συγχρονισμού</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Εικόνες</translation>
    </message>
    <message>
        <source>The device has been removed</source>
        <translation>Η συσκευή έχει αφαιρεθεί</translation>
    </message>
    <message>
        <source>This directory no longer exists</source>
        <translation>Ο φάκελος δεν υπάρχει</translation>
    </message>
    <message>
        <source>Calculating...</source>
        <translation>Υπολογισμός...</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Image Viewing</source>
        <translation>Προβολή εικόνας</translation>
    </message>
    <message>
        <source>Album</source>
        <translation>Άλμπουμ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Προβολή</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Παρουσίαση εικόνων</translation>
    </message>
    <message>
        <source>End show</source>
        <translation>Τέλος παρουσίασης</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>Αφαίρεση από το άλμπουμ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>Αγαπημένο</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>Μη αγαπημένο</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Περιστροφή δεξιά</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Περιστροφή αριστερά</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Θέσε ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Προβολή στον διαχειριστή αρχείον</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Πληροφοριες εικονας</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Προηγούμενο</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Επόμενο</translation>
    </message>
    <message>
        <source>Previous screen</source>
        <translation>Προηγούμενη οθόνη </translation>
    </message>
    <message>
        <source>Next screen</source>
        <translation>Επόμενη οθόνη</translation>
    </message>
    <message>
        <source>New album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="unfinished">Μετονομασία</translation>
    </message>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShortcutFrame</name>
    <message>
        <source>Album</source>
        <translation type="obsolete">Άλμπουμ</translation>
    </message>
</context>
<context>
    <name>ShortcutKey</name>
    <message>
        <source>View</source>
        <translation type="obsolete">Προβολή</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="obsolete">Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="obsolete">Παρουσίαση εικόνων</translation>
    </message>
    <message>
        <source>End show</source>
        <translation type="obsolete">Τέλος παρουσίασης</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="obsolete">Αντιγραφή</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="obsolete">Αφαίρεση από το άλμπουμ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="obsolete">Αγαπημένο</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="obsolete">Μη αγαπημένο</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="obsolete">Περιστροφή δεξιά</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="obsolete">Περιστροφή αριστερά</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="obsolete">Θέσε ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="obsolete">Προβολή στον διαχειριστή αρχείον</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="obsolete">Πληροφοριες εικονας</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation type="obsolete">Μετονομασία</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>Προηγούμενο</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Επόμενο</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TTBContent</name>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Previous</source>
        <translation type="unfinished">Προηγούμενο</translation>
    </message>
    <message>
        <source>Next</source>
        <translation type="unfinished">Επόμενο</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Περιστροφή αριστερά</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Περιστροφή δεξιά</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TTLContent</name>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image management</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>My favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Περιστροφή αριστερά</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Περιστροφή δεξιά</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished">Μη αγαπημένο</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">Αγαπημένο</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TitleFrame</name>
    <message>
        <source>View</source>
        <translation type="obsolete">Προβολή</translation>
    </message>
    <message>
        <source>Album</source>
        <translation type="obsolete">Άλμπουμ</translation>
    </message>
</context>
<context>
    <name>TopToolbar</name>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Ρυθμίσεις</translation>
    </message>
</context>
<context>
    <name>ViewPanel</name>
    <message>
        <source>Timeline</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to new album</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation type="unfinished">Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation type="unfinished">Παρουσίαση εικόνων</translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished">Αντιγραφή</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation type="unfinished">Αφαίρεση από το άλμπουμ</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished">Αγαπημένο</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished">Μη αγαπημένο</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation type="unfinished">Περιστροφή δεξιά</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation type="unfinished">Περιστροφή αριστερά</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation type="unfinished">Θέσε ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished">Προβολή στον διαχειριστή αρχείον</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation type="unfinished">Πληροφοριες εικονας</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
</context>
</TS>

==> deepin-image-viewer_5.8.15.orig.tar.xz: deepin-image-viewer-5.8.15/src/translations/deepin-image-viewer_el.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>HomePageWidget</name>
    <message>
        <source>Image file not found</source>
        <translation></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Image Viewing</source>
        <translation>Προβολή εικόνας</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Ρυθμίσεις</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Πλήρης οθόνη</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation></translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation></translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>Παρουσίαση εικόνων</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Μετονομασία</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation></translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>Περιστροφή δεξιά</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>Περιστροφή αριστερά</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>Θέσε ως ταπετσαρία</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>Προβολή στον διαχειριστή αρχείον</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>Πληροφοριες εικονας</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>Προηγούμενο</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>Επόμενο</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation></translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation></translation>
    </message>
    <message>
        <source>Open</source>
        <translation></translation>
    </message>
    <message>
        <source>Help</source>
        <translation></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Image Viewer</source>
        <translation></translation>
    </message>
    <message>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation></translation>
    </message>
</context>
</TS>
